Examples
=====================

A few examples are available as rendered IPython notebooks.


	  
Building a stream
''''''''''''''''''''''''''

How to build a stream:
`Building stream <examples/building.html>`_


Anaysing calibration
'''''''''''''''''''''''

How to analyse calibration:
`Analyse calibration <examples/calibration.html>`_
